@@ -8,13 +8,19 @@ from __future__ import print_function
 
 import argparse
 from collections import defaultdict, OrderedDict
-import cPickle
 import logging
 import importlib
 import os
 import sys
 import textwrap
 
+PY3 = sys.version_info[0] > 2
+
+if PY3:
+    import pickle
+else:
+    import cPickle as pickle
+
 import fantail
 
 logformat = "%(levelname)s|%(name)s|%(module)s|%(message)s"
@@ -58,8 +64,8 @@ def get_config(name,
 
     if db_existed:
         lg.debug("opening cached configuration: %s", conf_location)
-        with open(conf_location) as F:
-            conf = cPickle.load(F)
+        with open(conf_location, 'rb') as F:
+            conf = pickle.load(F)
     else:
         conf = fantail.Fantail()
 
@@ -90,11 +96,11 @@ def get_config(name,
         save_conf_locations(conf_fof, conflocs)
 
     for name, location in conflocs.items():
-        lg.warning("loading config '{}': {}".format(name, location))
+        lg.debug("loading config '{}': {}".format(name, location))
         conf.update(fantail.load(location))
 
     with open(conf_location, 'wb') as F:
-        cPickle.dump(conf, F)
+        pickle.dump(conf, F)
 
     return conf
 
@@ -120,6 +126,9 @@ def get_local_config_file(name):
 
 def save_local_config_file(lconf, name):
     fn = get_local_config_filename(name)
+    fnd = os.path.dirname(fn)
+    if not os.path.exists(fnd):
+        os.makedirs(fnd)
     fantail.yaml_file_save(lconf, fn)
 
 
@@ -396,7 +405,11 @@ class app(object):
         # create a help text from the docstring - if possible
         _desc = [cname]
         if function.__doc__:
-            _desc = function.__doc__.strip().split("\n", 1)
+            doc = function.__doc__.strip()
+            if '---' in doc:
+                doc = doc.split('---', 1)[0].strip()
+
+            _desc = doc.split("\n", 1)
 
         if len(_desc) == 2:
             short_description, long_description = _desc
@@ -648,9 +661,9 @@ def conf_show(app, args):
         if len(val) > 60:
             val = (" ".join(val.split()))[:60] + '...'
         if args.prefix:
-            print('{0}.{1}: {2}'.format(args.prefix, k, val))
+            print('{0}.{1} {2}'.format(args.prefix, k, val))
         else:
-            print('{0}: {1}'.format(k, val))
+            print('{0} {1}'.format(k, val))
 
 
 @arg("prefix", nargs='?')
@@ -736,15 +749,15 @@ def _conf_set(app, args):
     elif isint(nval):
         nval = int(nval)
 
-    print("{} {} {}".format(args.name, curval, nval))
+    #print("{} {} {}".format(args.name, curval, nval))
 
     if curval and isinstance(curval, fantail.Fantail):
-        lg.warning("Cannot overwrite a branch")
+        lg.info("Cannot overwrite a branch")
         exit(-1)
 
     app.conf[args.name] = nval
     with open(get_conf_pickle_location(app.name), 'wb') as F:
-        cPickle.dump(app.conf, F)
+        pickle.dump(app.conf, F)
 
     localconf = get_local_config_file(app.name)
     localconf[args.name] = nval
